import consola from "consola";
import * as dotenvSafe from "dotenv-safe";
import "reflect-metadata";
import { createExpressServer } from "routing-controllers";
import authchecker from "./authchecker";
import loaders from "./loaders/index";
import { ErrorHandler } from './middlewares/ErrorHandler';
import { JWTAuth } from './middlewares/JWTAuth';

dotenvSafe.config();
const PORT = process.env.APP_PORT || 4010;

const app = createExpressServer({
  authorizationChecker: authchecker,
  middlewares: [ErrorHandler, JWTAuth],
  development: process.env.NODE_ENV === "production",
  cors: true,
  routePrefix: "/api",
  controllers: [__dirname + "/controllers/*.ts"],
});

async function main() {
  await loaders(app);
  app.listen(PORT, () => {
    consola.success(
      `⚡️[server]: Server is running at http://localhost:${PORT}`
    );
  });
}
main();
