import { IsString } from 'class-validator';
import * as jsonwebtoken from 'jsonwebtoken';
import { getConnectionManager } from 'typeorm';
import { IllegalJWTError, JwtNotProvidedError, RefreshTokenCountInvalidError, UserNotFoundError } from '../../errors/AuthError';
import { Auth } from '../entities/Auth';
import { User } from '../entities/User';

export class RefreshAuth {
    @IsString()
    token: string;

    public async toAuth(): Promise<Auth> {
        let newAuth: Auth = new Auth();
        if (!this.token || this.token === undefined) {
            throw new JwtNotProvidedError()
        }
        let decoded
        try {
            decoded = jsonwebtoken.verify(this.token, 'securekey')
        } catch (error) {
            throw new IllegalJWTError()
        }
        console.log(decoded["userid"]);
        const found_user = await getConnectionManager().get().getRepository(User).findOne({ id: decoded["userid"] });
        if (!found_user) {
            throw new UserNotFoundError()
        }
        if (found_user.refreshTokenCount !== decoded["refreshtokencount"]) {
            throw new RefreshTokenCountInvalidError()
        }
        console.log(found_user);
        // delete found_user.password;
        newAuth.access_token = "ja"
        newAuth.access_token_expires_at = 5555555
        newAuth.refresh_token = "ja"
        newAuth.refresh_token_expires_at = 555555

        return newAuth;
    }
}